
[![maintained](https://img.shields.io/maintenance/yes/2020.svg?style=flat)](#)
[![maintainer](https://img.shields.io/badge/maintainer-%20%40korasinski-blue.svg?style=flat)](#)
[![release](https://img.shields.io/github/v/release/korasinski/pyNetia?color=yellow)](https://github.com/korasinski/pyNetia/releases)
[![buymeacaffe](https://img.shields.io/static/v1.svg?label=%20&message=Buy%20me%20a%20coffee&color=6f4e37&logo=buy%20me%20a%20coffee&logoColor=white)](https://www.buymeacoffee.com/korasinski)


# pyNetia
Python wrapper for communication with the Netia Player TV box using HTTP API.  

Currently supported device: _Netgem N7800 (Netia Player 2.0)_

Built for the custom component addon in **Home Assistant** - [ha-netia](https://github.com/korasinski/ha-netia).
